@@ -1,4 +1,5 @@
 from .constants import LIBRARY_PATH
+from .utils import get_name
 
 import os
 import sys
@@ -9,7 +10,7 @@ try:
     library = set(os.path.splitext(lib)[0] for lib in os.listdir(LIBRARY_PATH))
 except BaseException as e:
     library = set()
-    print("Error: can't access directory {!r}: {}".format(LIBRARY_PATH, e), file=sys.stderr)
+    print("can't access directory {!r}: {}: {}".format(LIBRARY_PATH, get_name(e), e), file=sys.stderr)
 
 modules = dict()
 hook = None
\ No newline at end of file
