@@ -1,5 +1,5 @@
-__version__ = '1.3.1'
-__date__ = '26 October 2025, 14:00 UTC+7'
+__version__ = '1.4.0'
+__date__ = '1 November 2025, 16:20 UTC+7'
 
 version = '{} ({})'.format(__version__, __date__)
 version_info = None
\ No newline at end of file
